
/* Generated data (by glib-mkenums) */

#ifndef __CHAMPLAIN_ENUM_TYPES_H__
#define __CHAMPLAIN_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "champlain-view.h" */
GType champlain_scroll_mode_get_type (void) G_GNUC_CONST;
#define CHAMPLAIN_TYPE_SCROLL_MODE champlain_scroll_mode_get_type()
GType champlain_unit_get_type (void) G_GNUC_CONST;
#define CHAMPLAIN_TYPE_UNIT champlain_unit_get_type()

/* enumerations from "champlain-selection-layer.h" */
GType champlain_selection_mode_get_type (void) G_GNUC_CONST;
#define CHAMPLAIN_TYPE_SELECTION_MODE champlain_selection_mode_get_type()

/* enumerations from "champlain-tile.h" */
GType champlain_state_get_type (void) G_GNUC_CONST;
#define CHAMPLAIN_TYPE_STATE champlain_state_get_type()

/* enumerations from "champlain-map-source.h" */
GType champlain_map_projection_get_type (void) G_GNUC_CONST;
#define CHAMPLAIN_TYPE_MAP_PROJECTION champlain_map_projection_get_type()
G_END_DECLS

#endif /* __CHAMPLAIN_ENUM_TYPES_H__ */

/* Generated data ends here */

